==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datalakeanalytics/kotlin/inputs/CreateComputePolicyWithAccountParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datalakeanalytics.kotlin.inputs

import com.pulumi.azurenative.datalakeanalytics.inputs.CreateComputePolicyWithAccountParametersArgs.builder
import com.pulumi.azurenative.datalakeanalytics.kotlin.enums.AADObjectType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The parameters used to create a new compute policy while creating a new Data Lake Analytics account.
 * @property maxDegreeOfParallelismPerJob The maximum degree of parallelism per job this user can use to submit jobs. This property, the min priority per job property, or both must be passed.
 * @property minPriorityPerJob The minimum priority per job this user can use to submit jobs. This property, the max degree of parallelism per job property, or both must be passed.
 * @property name The unique name of the compute policy to create.
 * @property objectId The AAD object identifier for the entity to create a policy for.
 * @property objectType The type of AAD object the object identifier refers to.
 */
public data class CreateComputePolicyWithAccountParametersArgs(
    public val maxDegreeOfParallelismPerJob: Output<Int>? = null,
    public val minPriorityPerJob: Output<Int>? = null,
    public val name: Output<String>,
    public val objectId: Output<String>,
    public val objectType: Output<Either<String, AADObjectType>>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datalakeanalytics.inputs.CreateComputePolicyWithAccountParametersArgs> {
    override fun toJava():
        com.pulumi.azurenative.datalakeanalytics.inputs.CreateComputePolicyWithAccountParametersArgs =
        com.pulumi.azurenative.datalakeanalytics.inputs.CreateComputePolicyWithAccountParametersArgs.builder()
            .maxDegreeOfParallelismPerJob(maxDegreeOfParallelismPerJob?.applyValue({ args0 -> args0 }))
            .minPriorityPerJob(minPriorityPerJob?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .objectId(objectId.applyValue({ args0 -> args0 }))
            .objectType(
                objectType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [CreateComputePolicyWithAccountParametersArgs].
 */
@PulumiTagMarker
public class CreateComputePolicyWithAccountParametersArgsBuilder internal constructor() {
    private var maxDegreeOfParallelismPerJob: Output<Int>? = null

    private var minPriorityPerJob: Output<Int>? = null

    private var name: Output<String>? = null

    private var objectId: Output<String>? = null

    private var objectType: Output<Either<String, AADObjectType>>? = null

    /**
     * @param value The maximum degree of parallelism per job this user can use to submit jobs. This property, the min priority per job property, or both must be passed.
     */
    @JvmName("rlxlxquoffgtciuy")
    public suspend fun maxDegreeOfParallelismPerJob(`value`: Output<Int>) {
        this.maxDegreeOfParallelismPerJob = value
    }

    /**
     * @param value The minimum priority per job this user can use to submit jobs. This property, the max degree of parallelism per job property, or both must be passed.
     */
    @JvmName("gpujweuulxpvwrbj")
    public suspend fun minPriorityPerJob(`value`: Output<Int>) {
        this.minPriorityPerJob = value
    }

    /**
     * @param value The unique name of the compute policy to create.
     */
    @JvmName("kqaewujwenlrywcl")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The AAD object identifier for the entity to create a policy for.
     */
    @JvmName("mnktcywhhjbprgus")
    public suspend fun objectId(`value`: Output<String>) {
        this.objectId = value
    }

    /**
     * @param value The type of AAD object the object identifier refers to.
     */
    @JvmName("mdkckhmwjdoffcsj")
    public suspend fun objectType(`value`: Output<Either<String, AADObjectType>>) {
        this.objectType = value
    }

    /**
     * @param value The maximum degree of parallelism per job this user can use to submit jobs. This property, the min priority per job property, or both must be passed.
     */
    @JvmName("ujhmrknkbswtaeex")
    public suspend fun maxDegreeOfParallelismPerJob(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxDegreeOfParallelismPerJob = mapped
    }

    /**
     * @param value The minimum priority per job this user can use to submit jobs. This property, the max degree of parallelism per job property, or both must be passed.
     */
    @JvmName("ueggrkpeiihbbbil")
    public suspend fun minPriorityPerJob(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minPriorityPerJob = mapped
    }

    /**
     * @param value The unique name of the compute policy to create.
     */
    @JvmName("etkihqxerklirgxr")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The AAD object identifier for the entity to create a policy for.
     */
    @JvmName("qqgrpaiolekicpdu")
    public suspend fun objectId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectId = mapped
    }

    /**
     * @param value The type of AAD object the object identifier refers to.
     */
    @JvmName("qyggtytvftkjybms")
    public suspend fun objectType(`value`: Either<String, AADObjectType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    /**
     * @param value The type of AAD object the object identifier refers to.
     */
    @JvmName("cfohycprdskxplfx")
    public fun objectType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AADObjectType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    /**
     * @param value The type of AAD object the object identifier refers to.
     */
    @JvmName("nqdukulqqoefnclk")
    public fun objectType(`value`: AADObjectType) {
        val toBeMapped = Either.ofRight<String, AADObjectType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    internal fun build(): CreateComputePolicyWithAccountParametersArgs =
        CreateComputePolicyWithAccountParametersArgs(
            maxDegreeOfParallelismPerJob = maxDegreeOfParallelismPerJob,
            minPriorityPerJob = minPriorityPerJob,
            name = name ?: throw PulumiNullFieldException("name"),
            objectId = objectId ?: throw PulumiNullFieldException("objectId"),
            objectType = objectType ?: throw PulumiNullFieldException("objectType"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datalakeanalytics/kotlin/inputs/CreateComputePolicyWithAccountParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datalakeanalytics.kotlin.inputs

import com.pulumi.azurenative.datalakeanalytics.inputs.CreateComputePolicyWithAccountParametersArgs.builder
import com.pulumi.azurenative.datalakeanalytics.kotlin.enums.AADObjectType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The parameters used to create a new compute policy while creating a new Data Lake Analytics account.
 * @property maxDegreeOfParallelismPerJob The maximum degree of parallelism per job this user can use to submit jobs. This property, the min priority per job property, or both must be passed.
 * @property minPriorityPerJob The minimum priority per job this user can use to submit jobs. This property, the max degree of parallelism per job property, or both must be passed.
 * @property name The unique name of the compute policy to create.
 * @property objectId The AAD object identifier for the entity to create a policy for.
 * @property objectType The type of AAD object the object identifier refers to.
 */
public data class CreateComputePolicyWithAccountParametersArgs(
    public val maxDegreeOfParallelismPerJob: Output<Int>? = null,
    public val minPriorityPerJob: Output<Int>? = null,
    public val name: Output<String>,
    public val objectId: Output<String>,
    public val objectType: Output<Either<String, AADObjectType>>,
) :
    ConvertibleToJava<com.pulumi.azurenative.datalakeanalytics.inputs.CreateComputePolicyWithAccountParametersArgs> {
    override fun toJava():
        com.pulumi.azurenative.datalakeanalytics.inputs.CreateComputePolicyWithAccountParametersArgs =
        com.pulumi.azurenative.datalakeanalytics.inputs.CreateComputePolicyWithAccountParametersArgs.builder()
            .maxDegreeOfParallelismPerJob(maxDegreeOfParallelismPerJob?.applyValue({ args0 -> args0 }))
            .minPriorityPerJob(minPriorityPerJob?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .objectId(objectId.applyValue({ args0 -> args0 }))
            .objectType(
                objectType.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [CreateComputePolicyWithAccountParametersArgs].
 */
@PulumiTagMarker
public class CreateComputePolicyWithAccountParametersArgsBuilder internal constructor() {
    private var maxDegreeOfParallelismPerJob: Output<Int>? = null

    private var minPriorityPerJob: Output<Int>? = null

    private var name: Output<String>? = null

    private var objectId: Output<String>? = null

    private var objectType: Output<Either<String, AADObjectType>>? = null

    /**
     * @param value The maximum degree of parallelism per job this user can use to submit jobs. This property, the min priority per job property, or both must be passed.
     */
    @JvmName("rxipgjevhlpihtea")
    public suspend fun maxDegreeOfParallelismPerJob(`value`: Output<Int>) {
        this.maxDegreeOfParallelismPerJob = value
    }

    /**
     * @param value The minimum priority per job this user can use to submit jobs. This property, the max degree of parallelism per job property, or both must be passed.
     */
    @JvmName("qvwoifmrkyqgvboo")
    public suspend fun minPriorityPerJob(`value`: Output<Int>) {
        this.minPriorityPerJob = value
    }

    /**
     * @param value The unique name of the compute policy to create.
     */
    @JvmName("mfsbdcpoftxgusyn")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The AAD object identifier for the entity to create a policy for.
     */
    @JvmName("vrnouvlujghqqckk")
    public suspend fun objectId(`value`: Output<String>) {
        this.objectId = value
    }

    /**
     * @param value The type of AAD object the object identifier refers to.
     */
    @JvmName("khycimbilissqnwu")
    public suspend fun objectType(`value`: Output<Either<String, AADObjectType>>) {
        this.objectType = value
    }

    /**
     * @param value The maximum degree of parallelism per job this user can use to submit jobs. This property, the min priority per job property, or both must be passed.
     */
    @JvmName("rhxyfrtdmaubuyxx")
    public suspend fun maxDegreeOfParallelismPerJob(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxDegreeOfParallelismPerJob = mapped
    }

    /**
     * @param value The minimum priority per job this user can use to submit jobs. This property, the max degree of parallelism per job property, or both must be passed.
     */
    @JvmName("vhedkrflgwdmdvqd")
    public suspend fun minPriorityPerJob(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minPriorityPerJob = mapped
    }

    /**
     * @param value The unique name of the compute policy to create.
     */
    @JvmName("quxufgpfrryquxne")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The AAD object identifier for the entity to create a policy for.
     */
    @JvmName("cvuipsrgtlcwshpy")
    public suspend fun objectId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectId = mapped
    }

    /**
     * @param value The type of AAD object the object identifier refers to.
     */
    @JvmName("lioncgnxgxikqsxk")
    public suspend fun objectType(`value`: Either<String, AADObjectType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    /**
     * @param value The type of AAD object the object identifier refers to.
     */
    @JvmName("ejaxbonjlawhfygl")
    public fun objectType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AADObjectType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    /**
     * @param value The type of AAD object the object identifier refers to.
     */
    @JvmName("inuvvfdkekmxaplf")
    public fun objectType(`value`: AADObjectType) {
        val toBeMapped = Either.ofRight<String, AADObjectType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    internal fun build(): CreateComputePolicyWithAccountParametersArgs =
        CreateComputePolicyWithAccountParametersArgs(
            maxDegreeOfParallelismPerJob = maxDegreeOfParallelismPerJob,
            minPriorityPerJob = minPriorityPerJob,
            name = name ?: throw PulumiNullFieldException("name"),
            objectId = objectId ?: throw PulumiNullFieldException("objectId"),
            objectType = objectType ?: throw PulumiNullFieldException("objectType"),
        )
}
